==> 2.5.0.zip: cloudlog/application/language/russian/menu_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['menu_badge_developer_mode'] = 'Режим разработчика';

$lang['menu_logbook'] = 'Журнал';
$lang['menu_overview'] = 'Обычный вид';
$lang['menu_advanced'] = 'Расширенный вид';

$lang['menu_qso'] = 'QSO';
$lang['menu_live_qso'] = 'добавить QSO';
$lang['menu_post_qso'] = 'добавить прошедшее QSO';
$lang['menu_fast_log_entry'] = "Simple Fast Log Entry";
$lang['menu_live_contest_logging'] = 'Журнал соревнований';
$lang['menu_post_contest_logging'] = 'Журнал прошедших соревнований';
$lang['menu_bandmap'] = 'План диапазонов';
$lang['menu_view_qsl'] = 'Просмотр QSL';
$lang['menu_view_eqsl'] = 'Просмотр eQSL';

$lang['menu_notes'] = 'Заметки';

$lang['menu_analytics'] = 'Аналитика';
$lang['menu_statistics'] = 'Статистика';
$lang['menu_gridsquares'] = 'Квадраты';
$lang['menu_gridmap'] = 'Карта квадратов';
$lang['menu_activated_gridsquares'] = 'Активированные квадраты';
$lang['menu_gridsquare_activators'] = 'Активаторы квадратов';
$lang['menu_distances_worked'] = 'Сработанные дистанции';
$lang['menu_days_with_qsos'] = 'Дней с QSO';
$lang['menu_timeline'] = 'Лента событий';
$lang['menu_accumulated_statistics'] = 'Объединённая статистика';
$lang['menu_timeplotter'] = 'Графики';
$lang['menu_custom_maps'] = 'Карты';
$lang['menu_continents'] = 'Континенты';

$lang['menu_awards'] = 'Дипломы';
$lang['menu_cq'] = 'CQ';
$lang['menu_dok'] = 'DOK';
$lang['menu_dxcc'] = 'DXCC';
$lang['menu_iota'] = 'IOTA';
$lang['menu_pota'] = 'POTA';
$lang['menu_sig'] = 'SIG';
$lang['menu_sota'] = 'SOTA';
$lang['menu_us_counties'] = 'US Counties';
$lang['menu_us_gridmaster'] = 'US Gridmaster';
$lang['menu_vucc'] = 'VUCC';
$lang['menu_was'] = 'WAS';
$lang['menu_wwff'] = 'WWFF';

$lang['menu_admin'] = 'Администрирование';
$lang['menu_user_account'] = 'Аккаунты пользователей';
$lang['menu_global_options'] = 'Общие настройки';
$lang['menu_modes'] = 'Виды модуляции';
$lang['menu_contests'] = 'Соревнования';
$lang['menu_themes'] = 'Темы оформления';
$lang['menu_backup'] = 'Резервное копирование';
$lang['menu_update_country_files'] = 'Обновить файлы стран';
$lang['menu_debug_information'] = 'Отладочная информация';

$lang['menu_search_text'] = 'Поиск позывного';

$lang['menu_search_button'] = 'Поиск';
$lang['menu_login_button'] = 'Вход';

$lang['menu_account'] = 'Аккаунт';
$lang['menu_station_logbooks'] = 'Аппаратные журналы';
$lang['menu_station_locations'] = 'Расположения станции';
$lang['menu_bands'] = 'Диапазоны';
$lang['menu_adif_import_export'] = 'Импорт / экспорт ADIF';
$lang['menu_kml_export'] = 'Экспорт KML';
$lang['menu_dx_atlas_gridsquare_export'] = 'Экспорт квадратов DX Atlas';
$lang['menu_sota_csv_export'] = 'Экспорт SOTA CSV';
$lang['menu_cabrillo_export'] = 'Экспорт Cabrillo';
$lang['menu_oqrs_requests'] = 'Запросы OQRS';
$lang['menu_print_requested_qsls'] = 'Распечатать запрошенные QSL';
$lang['menu_labels'] = 'Наклейки';
$lang['menu_logbook_of_the_world'] = 'Logbook of the World';
$lang['menu_eqsl_import_export'] = 'Импорт / экспорт eQSL';
$lang['menu_qrz_logbook'] = 'QRZ Logbook';
$lang['menu_hrd_logbook'] = 'HRDLog Logbook';
$lang['menu_qo_100_dx_club_upload'] = 'Загрузка в QO-100 Dx Club';
$lang['menu_api_keys'] = 'ключи API';
$lang['menu_hardware_interfaces'] = 'Аппаратные интерфейсы';
$lang['menu_help'] = 'Помощь';
$lang['menu_forum'] = 'Форум';
$lang['menu_logout'] = 'Выход';

$lang['menu_ffma'] = "Fred Fish Memorial Award";
$lang['menu_ja_gridmaster'] = 'JA Gridmaster';
$lang['menu_maintenance']='Maintenance';

==> 2.6.4.zip: cloudlog/application/language/russian/menu_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['menu_badge_developer_mode'] = 'Режим разработчика';

$lang['menu_logbook'] = 'Журнал';
$lang['menu_overview'] = 'Обычный вид';
$lang['menu_advanced'] = 'Расширенный вид';

$lang['menu_qso'] = 'QSO';
$lang['menu_live_qso'] = 'добавить QSO';
$lang['menu_post_qso'] = 'добавить прошедшее QSO';
$lang['menu_fast_log_entry'] = "Simple Fast Log Entry";
$lang['menu_live_contest_logging'] = 'Журнал соревнований';
$lang['menu_post_contest_logging'] = 'Журнал прошедших соревнований';
$lang['menu_bandmap'] = 'План диапазонов';
$lang['menu_view_qsl'] = 'Просмотр QSL';
$lang['menu_view_eqsl'] = 'Просмотр eQSL';

$lang['menu_notes'] = 'Заметки';

$lang['menu_analytics'] = 'Аналитика';
$lang['menu_statistics'] = 'Статистика';
$lang['menu_gridsquares'] = 'Квадраты';
$lang['menu_gridmap'] = 'Карта квадратов';
$lang['menu_activated_gridsquares'] = 'Активированные квадраты';
$lang['menu_gridsquare_activators'] = 'Активаторы квадратов';
$lang['menu_distances_worked'] = 'Сработанные дистанции';
$lang['menu_days_with_qsos'] = 'Дней с QSO';
$lang['menu_timeline'] = 'Лента событий';
$lang['menu_accumulated_statistics'] = 'Объединённая статистика';
$lang['menu_timeplotter'] = 'Графики';
$lang['menu_custom_maps'] = 'Карты';
$lang['menu_continents'] = 'Континенты';

$lang['menu_awards'] = 'Дипломы';
$lang['menu_cq'] = 'CQ';
$lang['menu_dl_gridmaster'] = 'DL Gridmaster';
$lang['menu_dok'] = 'DOK';
$lang['menu_dxcc'] = 'DXCC';
$lang['menu_iota'] = 'IOTA';
$lang['menu_lx_gridmaster'] = 'LX Gridmaster';
$lang['menu_pota'] = 'POTA';
$lang['menu_sig'] = 'SIG';
$lang['menu_sota'] = 'SOTA';
$lang['menu_us_counties'] = 'US Counties';
$lang['menu_us_gridmaster'] = 'US Gridmaster';
$lang['menu_vucc'] = 'VUCC';
$lang['menu_waja'] = 'WAJA';
$lang['menu_was'] = 'WAS';
$lang['menu_wwff'] = 'WWFF';

$lang['menu_admin'] = 'Администрирование';
$lang['menu_user_account'] = 'Аккаунты пользователей';
$lang['menu_global_options'] = 'Общие настройки';
$lang['menu_modes'] = 'Виды модуляции';
$lang['menu_contests'] = 'Соревнования';
$lang['menu_themes'] = 'Темы оформления';
$lang['menu_backup'] = 'Резервное копирование';
$lang['menu_update_country_files'] = 'Обновить файлы стран';
$lang['menu_debug_information'] = 'Отладочная информация';

$lang['menu_search_text'] = 'Поиск позывного';
$lang['menu_search_text_quicklog'] = "Добавить/Найти позывной";

$lang['menu_search_button'] = 'Поиск';
$lang['menu_search_button_qicksearch_log'] = "Журнал";
$lang['menu_login_button'] = 'Вход';

$lang['menu_account'] = 'Аккаунт';
$lang['menu_station_logbooks'] = 'Журналы';
$lang['menu_station_locations'] = 'Местоположения станции';
$lang['menu_bands'] = 'Диапазоны';
$lang['menu_adif_import_export'] = 'Импорт / экспорт ADIF';
$lang['menu_kml_export'] = 'Экспорт KML';
$lang['menu_dx_atlas_gridsquare_export'] = 'Экспорт квадратов DX Atlas';
$lang['menu_sota_csv_export'] = 'Экспорт SOTA CSV';
$lang['menu_cabrillo_export'] = 'Экспорт Cabrillo';
$lang['menu_oqrs_requests'] = 'Запросы OQRS';
$lang['menu_print_requested_qsls'] = 'Распечатать запрошенные QSL';
$lang['menu_labels'] = 'Наклейки';
$lang['menu_logbook_of_the_world'] = 'Logbook of the World';
$lang['menu_eqsl_import_export'] = 'Импорт / экспорт eQSL';
$lang['menu_qrz_logbook'] = 'QRZ Logbook';
$lang['menu_hrd_logbook'] = 'HRDLog Logbook';
$lang['menu_qo_100_dx_club_upload'] = 'Загрузка в QO-100 Dx Club';
$lang['menu_api_keys'] = 'ключи API';
$lang['menu_hardware_interfaces'] = 'Аппаратные интерфейсы';
$lang['menu_help'] = 'Помощь';
$lang['menu_forum'] = 'Форум';
$lang['menu_logout'] = 'Выход';

$lang['menu_ffma'] = "Fred Fish Memorial Award";
$lang['menu_ja_gridmaster'] = 'JA Gridmaster';
$lang['menu_maintenance']='Обслуживание';
